@@ -12,6 +12,9 @@ from .decorators import add_write_method, add_run_method
 from dnora.defaults import read_environment_variable
 from typing import Union, Optional
 
+from geo_parameters.metaparameter import MetaParameter
+import geo_parameters as gp
+
 
 @add_run_method(DnoraFileType.INPUT)
 @add_run_method(DnoraFileType.SPECTRA)
@@ -33,6 +36,8 @@ from typing import Union, Optional
 class ModelExecuter:
     _input_file_writers = {}
     _model_runners = {}
+    _output_var_aliases = {}
+    _output_vars = []
 
     def _get_default_format(self) -> str:
         return ModelFormat.MODELRUN
@@ -47,10 +52,50 @@ class ModelExecuter:
             for name, nest in self.model.nest(get_dict=True).items():
                 msg.plain(f"Will execute '{name}' inside '{model.grid().name}'")
                 self._nest[name] = self.__class__(nest)
+        self.set_output_vars(self._output_vars)
 
     def dry_run(self) -> bool:
         return self._dry_run or self.model.dry_run()
 
+    def set_output_vars(
+        self,
+        output_vars: list[Union[MetaParameter, str]],
+        verbose: bool = False,
+    ) -> None:
+        """Set the output variables that will be used when running the model"""
+        self._output_vars = []
+        self.add_output_vars(output_vars=output_vars, verbose=verbose)
+
+    def add_output_vars(
+        self,
+        output_vars: list[Union[MetaParameter, str]],
+        verbose: bool = False,
+    ) -> None:
+        """Adds output variables for the wave model while keeping the old ones"""
+        if not isinstance(output_vars, list):
+            output_vars = [output_vars]
+
+        for var in output_vars:
+            if isinstance(var, str):
+                if verbose:
+                    msg.plain(f"Mapping '{var}' >> '{var}'")
+                self._output_vars.append(var)
+            elif gp.is_gp(var):
+                key = var.find_me_in(self._output_var_aliases.keys(), return_first=True)
+                if key is None:
+                    msg.info(
+                        f"Cannot find variable {var} in the alias list! Skipping..."
+                    )
+                else:
+                    model_var = self._output_var_aliases.get(key)
+                    if verbose:
+                        msg.plain(f"Mapping {key} >> '{model_var}'")
+                    self._output_vars.append(model_var)
+            else:
+                raise TypeError(
+                    f"Variables need to be of type 'str' or geo-parameters, not {var}!"
+                )
+
     def _write(
         self,
         file_type: Union[DnoraFileType, str],
@@ -104,6 +149,7 @@ class ModelExecuter:
                 self.model,
                 file_object,
                 exported_files=self.model.exported_files(),
+                output_vars=self._output_vars,
                 **kwargs,
             )
             if not isinstance(output_files, list):
